@@ -406,7 +406,7 @@ class SOFEvent:
 
     def __eq__(self, other):
         if (isinstance(other, SOFEvent)):
-            return self.id == other.id and self.type == other.type and self.startdatetime == other.startdatetime and self.description == other.description
+            return self.type == other.type and self.startdatetime == other.startdatetime and self.description == other.description
         return False
 
     def __str__(self):
